-- winlibSimple
-- Jean-Marc Duro and Irv Mullins
-- 2015
--
include std/search.e
public include win32lib.ew

-- stores object ids with their class
export object registry = {}

constant WIN32LIB_CLASSES = {  -- class, className, classType},
  {Window, "Window"},                {PushButton, "PushButton"},
  {DefPushButton, "DefPushButton"},  {CancelButton, "CancelButton"},
  {CheckBox, "CheckBox"},            {TriCheckBox, "TriCheckBox"},
  {Radio, "Radio"},                  {Group, "Group"},
  {SortedList, "SortedList"},        {List, "List"},
  {Combo, "Combo"},                  {SortedCombo, "SortedCombo"},
  {SimpleCombo, "SimpleCombo"},      {DropDownList, "DropDownList"},
  {EditText, "EditText"},            {MleText, "MleText"},
  {LText, "LText"},                  {RText, "RText"},
  {CText, "CText"},                  {HScroll, "HScroll"},
  {VScroll, "VScroll"},              {Icon, "Icon"},
  {Bitmap, "Bitmap"},                {Menu, "Menu"},
  {Popup, "Popup"},                  {MenuItem, "MenuItem"},
  {MenuSpacer, "MenuSpacer"},        {Pixmap, "Pixmap"},
  {ToolBar, "ToolBar"},              {StatusBar, "StatusBar"},
  {PictureButton, "PictureButton"},  {ToggleButton, "ToggleButton"},
  {TogglePicture, "TogglePicture"},  {HTrackBar, "HTrackBar"},
  {VTrackBar, "VTrackBar"},          {TabControl, "TabControl"},
  {TabItem, "TabItem"},              {ProgressBar, "ProgressBar"},
  {ListView, "ListView"},            {TreeView, "TreeView"},
  {RichEdit, "RichEdit"},            {MonthCalendar, "MonthCalendar"},
  {UpDown, "UpDown"},                {ReBar, "ReBar"},
  {ToolTip, "ToolTip"},              {FlatToolBar, "FlatToolBar"},
  {SepButton, "SepButton"},          {ComboBoxEx, "ComboBoxEx"}
}

-- create a widget and store it in registry
public function createObject( integer class, object params )
  atom id = createEx( class, params[1], params[2], params[3], params[4], params[5], params[6], params[7], params[8] )
  registry = append(registry, {id, class})
  return id
end function

-- get the class of a widget
public function getClass(integer id)
  return vlookup(id, registry, 1, 2, -1)
end function

-- get the class name of a widget
public function getClassName(integer id)
  object class = vlookup(id, registry, 1, 2, -1)
  if atom(class) then
    return vlookup(class, WIN32LIB_CLASSES, 1, 2, "Unknown")
  end if
end function

-- set a property of a widget
public procedure setProperty(object Id, sequence Property, object Value, object Section=0)
  integer id, parent, param1, param2
  if sequence(Id) then
    parent = Id[1]
    id     = Id[2]
  else
    id     = Id
  end if
  if sequence(Section) then
    param1 = Section[1]
    param2 = Section[2]
  else
    param1 = Section
  end if
  atom class = getClass(id)
  switch class do
  case Window then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case PushButton then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case DefPushButton then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case CancelButton then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case CheckBox then 
    if equal(Property, "check") then
      setCheck( id, Value )
    end if
  case TriCheckBox then
    if equal(Property, "check") then
      setCheck( id, Value )
    end if
  case Radio then
    if equal(Property, "check") then
      setCheck( id, Value )
    end if
  case Group then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case SortedList then
    if equal(Property, "text") then
    end if
  case List then
    if equal(Property, "text") then
    end if
  case Combo then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case SortedCombo then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case SimpleCombo then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case DropDownList then
    if equal(Property, "text") then
    end if
  case EditText then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case MleText then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case LText then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case RText then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case CText then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case HScroll then
    if equal(Property, "text") then
    end if
  case VScroll then
    if equal(Property, "text") then
    end if
  case Icon then
    if equal(Property, "text") then
    end if
  case Bitmap then
    if equal(Property, "text") then
    end if
  case Menu then
    if equal(Property, "text") then
    end if
  case Popup then
    if equal(Property, "text") then
    end if
  case MenuItem then
    if equal(Property, "text") then
    end if
  case MenuSpacer then
    if equal(Property, "text") then
    end if
  case Pixmap then
    if equal(Property, "text") then
    end if
  case ToolBar then
    if equal(Property, "text") then
    end if
  case StatusBar then
    if equal(Property, "text") then
      if Section then
	    setText( {id, Section}, Value )
	  else
        setText( id, Value )
	  end if
    end if
  case PictureButton then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case ToggleButton then
    if equal(Property, "text") then
      setText( id, Value )
    elsif equal(Property, "check") then
      setCheck( id, Value )
    end if
  case TogglePicture then
    if equal(Property, "text") then
      setText( id, Value )
    elsif equal(Property, "check") then
      setCheck( id, Value )
    end if
  case HTrackBar then
    if equal(Property, "text") then
    end if
  case VTrackBar then
    if equal(Property, "text") then
    end if
  case TabControl then
    if equal(Property, "text") then
    end if
  case TabItem then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case ProgressBar then
    if equal(Property, "text") then
    end if
  case ListView then
    if equal(Property, "text") then
      setLVItemText( id, Section[1], Section[2], Value)
    end if
  case TreeView then
    if equal(Property, "text") then
    end if
  case RichEdit then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case MonthCalendar then
    if equal(Property, "text") then
    end if
  case UpDown then
    if equal(Property, "text") then
    end if
  case ReBar then
    if equal(Property, "text") then
    end if
  case ToolTip then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  case FlatToolBar then
    if equal(Property, "text") then
    end if
  case SepButton then
    if equal(Property, "text") then
    end if
  case ComboBoxEx then
    if equal(Property, "text") then
      setText( id, Value )
    end if
  end switch
end procedure

-- get a property of a widget
public function getProperty(object Id, sequence Property, object Section=0)
  integer id, parent, param1, param2
  object Value = 0
  if sequence(Id) then
    parent = Id[1]
    id     = Id[2]
  else
    id     = Id
  end if
  if sequence(Section) then
    param1 = Section[1]
    param2 = Section[2]
  else
    param1 = Section
  end if
  atom class = getClass(id)
  switch class do
  case Window then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case PushButton then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case DefPushButton then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case CancelButton then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case CheckBox then 
    if equal(Property, "text") then
    end if
  case TriCheckBox then
    if equal(Property, "text") then
    end if
  case Radio then
    if equal(Property, "text") then
    end if
  case Group then
    if equal(Property, "text") then
    end if
  case SortedList then
    if equal(Property, "text") then
    end if
  case List then
    if equal(Property, "text") then
    end if
  case Combo then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case SortedCombo then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case SimpleCombo then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case DropDownList then
    if equal(Property, "text") then
    end if
  case EditText then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case MleText then
    if equal(Property, "text") then
    end if
  case LText then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case RText then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case CText then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  case HScroll then
    if equal(Property, "text") then
    end if
  case VScroll then
    if equal(Property, "text") then
    end if
  case Icon then
    if equal(Property, "text") then
    end if
  case Bitmap then
    if equal(Property, "text") then
    end if
  case Menu then
    if equal(Property, "text") then
    end if
  case Popup then
    if equal(Property, "text") then
    end if
  case MenuItem then
    if equal(Property, "text") then
    end if
  case MenuSpacer then
    if equal(Property, "text") then
    end if
  case Pixmap then
    if equal(Property, "text") then
    end if
  case ToolBar then
    if equal(Property, "text") then
    end if
  case StatusBar then
    if equal(Property, "text") then
    end if
  case PictureButton then
    if equal(Property, "text") then
    end if
  case ToggleButton then
    if equal(Property, "text") then
    end if
  case TogglePicture then
    if equal(Property, "text") then
    end if
  case HTrackBar then
    if equal(Property, "text") then
    end if
  case VTrackBar then
    if equal(Property, "text") then
    end if
  case TabControl then
    if equal(Property, "text") then
    end if
  case TabItem then
    if equal(Property, "text") then
    end if
  case ProgressBar then
    if equal(Property, "text") then
    end if
  case ListView then
    if equal(Property, "text") then
      Value = getLVItemText(id, Section[1], Section[2])
    end if
  case TreeView then
    if equal(Property, "text") then
    end if
  case RichEdit then
    if equal(Property, "text") then
    end if
  case MonthCalendar then
    if equal(Property, "text") then
    end if
  case UpDown then
    if equal(Property, "text") then
    end if
  case ReBar then
    if equal(Property, "text") then
    end if
  case ToolTip then
    if equal(Property, "text") then
    end if
  case FlatToolBar then
    if equal(Property, "text") then
    end if
  case SepButton then
    if equal(Property, "text") then
    end if
  case ComboBoxEx then
    if equal(Property, "text") then
      Value = getText(id)
    end if
  end switch
  return Value
end function

